#!/bin/bash

version()
{
	echo "$0 version 0.1"
}

usage()
{
	echo "Create a new cross-binutils package with"
	echo "   $0 arch-name"
	echo "   arch-name: x86-64, arm, m68k, .."
}

TEMP=`getopt -o Vvh --long version,verbose,help -n 'create-cross.sh' -- "$@"`
if [ $? != 0 ] ; then echo "Terminating..." >&2 ; exit 1 ; fi                   
# Note the quotes around `$TEMP': they are essential!
eval set -- "$TEMP"

while true ; do
        case "$1" in
                -V|--version) version ; exit 0 ;;
                -v|--verbose) VERBOSE=1; shift ;;
		-h|--help)   version;  usage ; exit 0 ;;
                --) shift ; break ;;                                            
                *) echo "Internal error!" ; exit 1 ;;                           
        esac                                                                    
done                                                                            

if [ $# != 1 ]; then
	version
	usage
	exit 1
fi

if [ "`pwd|cut -f2 -d/`" == "work" ]; then
   echo "Please copy the binutils package to your local disk first."
   exit
fi

arch=$1

echo -n "Building package for $arch --> ../cross-$arch-binutils ..."

( 
  cd ..
  rm -rf cross-$arch-binutils
  cp -a binutils cross-$arch-binutils
  cd cross-$arch-binutils
  mv binutils.changes cross-$arch-binutils.changes
  mv binutils.spec cross-$arch-binutils.spec

  perl -pi -e "s/Name:.*binutils$/Name:         cross-$arch-binutils/g" \
		cross-$arch-binutils.spec
  perl -pi -e "s/changelog -n binutils$/changelog -n cross-$arch-binutils/g" \
		cross-$arch-binutils.spec


)

echo " done."
